@@ -20,6 +20,7 @@ from libzim.writer import (
     Creator,
     FileProvider,
     Hint,
+    IndexData,
     Item,
     StringProvider,
 )
@@ -254,7 +255,7 @@ def test_creator_nbworkers(fpath, lipsum_item, nb_workers):
 
 def test_creator_combine_config(fpath, lipsum_item):
     with Creator(fpath).config_verbose(True).config_compression(
-        "lzma"
+        "zstd"
     ).config_clustersize(1024).config_indexing(True, "eng").config_nbworkers(2) as c:
         c.add_item(lipsum_item)
 
@@ -263,7 +264,7 @@ def test_creator_combine_config(fpath, lipsum_item):
     "name, args",
     [
         ("verbose", (True,)),
-        ("compression", ("lzma",)),
+        ("compression", ("zstd",)),
         ("clustersize", (1024,)),
         ("indexing", (True, "eng")),
         ("nbworkers", (2,)),
@@ -639,6 +640,77 @@ def test_hints_values(fpath):
             )
 
 
+@pytest.mark.parametrize(
+    "indexData, customContent, search_expected",
+    [
+        (None, "", [("standard", 1), ("home", 0), ("computer", 0)]),
+        (False, "", [("standard", 1), ("home", 0), ("computer", 0)]),
+        (True, "home", [("standard", 1), ("home", 1), ("computer", 0)]),
+        (True, "computer", [("standard", 1), ("home", 0), ("computer", 1)]),
+        (True, "standard", [("standard", 2), ("home", 0), ("computer", 0)]),
+    ],
+)
+def test_custom_indexdata(
+    fpath, lipsum_item, lipsum, indexData, customContent, search_expected
+):
+    item = StaticItem(path=HOME_PATH + "custom", content=lipsum, mimetype="text/html")
+    if indexData is None:
+        item.get_indexdata = lambda: None
+    else:
+
+        class CustomIndexData(IndexData):
+            def has_indexdata(self):
+                return indexData
+
+            def get_title(self):
+                return ""
+
+            def get_content(self):
+                return customContent
+
+            def get_keywords(self):
+                return ""
+
+            def get_wordcount(self):
+                return 1
+
+        item.get_indexdata = CustomIndexData
+
+    with Creator(fpath).config_indexing(True, "eng") as c:
+        c.add_item(lipsum_item)
+        c.add_item(item)
+
+    zim = Archive(fpath)
+    searcher = Searcher(zim)
+    for search_query, expected in search_expected:
+        query = Query().set_query(search_query)
+        search = searcher.search(query)
+        assert search.getEstimatedMatches() == expected
+
+
+def test_indexdata_interface():
+    default_id = IndexData()
+    assert default_id.has_indexdata() is False
+    for method in ("title", "content", "keywords", "wordcount"):
+        with pytest.raises(NotImplementedError):
+            getattr(default_id, f"get_{method}")()
+    assert default_id.get_geoposition() is None
+
+
+def test_exc_in_indexdata(fpath, lipsum):
+    item = StaticItem(path=HOME_PATH + "custom", content=lipsum, mimetype="text/html")
+
+    class CustomIndexData(IndexData):
+        def has_indexdata(self):
+            raise IndexError
+
+    item.get_indexdata = CustomIndexData
+
+    with pytest.raises(RuntimeError, match="IndexError"):
+        with Creator(fpath).config_indexing(True, "eng") as c:
+            c.add_item(item)
+
+
 def test_reimpfeed(fpath):
     class AContentProvider:
         def __init__(self):
